bayespy.inference.vmp.nodes.gaussian.GaussianGammaARDDistribution.compute_phi_from_parents
==========================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaARDDistribution.compute_phi_from_parents